CoralogixIgnoredInstrument enum

Auto-instrumentation kinds that can be excluded when linking Dart-side work to an active global span (enforced in Dart, not native).

Inheritance
Available extensions

Values

networkRequests → const CoralogixIgnoredInstrument

Do not link CxHttpClient / CxDioInterceptor events to the active custom global span.

userInteractions → const CoralogixIgnoredInstrument

Do not link Dart-side user interaction events to the active custom global span.

errors → const CoralogixIgnoredInstrument

Do not link Dart-side reportError events to the active custom global span.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CoralogixIgnoredInstrument>
A constant List of the values in this enum, in order of their declaration.