getActiveGlobalSpanId static method
Active global span id for the current async zone, if any.
Implementation
static String? getActiveGlobalSpanId() =>
Zone.current[cxActiveSpanIdKey] as String?;
Active global span id for the current async zone, if any.
static String? getActiveGlobalSpanId() =>
Zone.current[cxActiveSpanIdKey] as String?;