onError method
Called when an exception was occurred during the request.
Implementation
@override
void onError(dio.DioException err, dio.ErrorInterceptorHandler handler) {
_report(err.requestOptions, error: err);
handler.next(err);
}
Called when an exception was occurred during the request.
@override
void onError(dio.DioException err, dio.ErrorInterceptorHandler handler) {
_report(err.requestOptions, error: err);
handler.next(err);
}