CXDomain enum

Inheritance
Available extensions

Values

eu1 → const CXDomain
eu2 → const CXDomain
us1 → const CXDomain
us2 → const CXDomain
us3 → const CXDomain
ap1 → const CXDomain
ap2 → const CXDomain
ap3 → const CXDomain
staging → const CXDomain

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String

Available on CXDomain, provided by the CoralogixDomainExtension extension

no setter
url → String

Available on CXDomain, provided by the CoralogixDomainExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CXDomain>
A constant List of the values in this enum, in order of their declaration.