CXExporterOptions class

Constructors

CXExporterOptions({required CXDomain coralogixDomain, UserMetadata? userContext, required String environment, required String application, required String version, required String publicKey, List<String>? ignoreUrls, List<String>? ignoreErrors, String? proxyUrl, Map<String, dynamic>? labels, int sdkSampler = 100, List<CXExcludableInstrumentation> excludeFromSampling = const [], int mobileVitalsFPSSamplingRate = 300, Map<String, bool>? instrumentations, bool collectIPData = true, bool debug = false, BeforeSendResult? beforeSend(EditableCxRumEvent event)?, void tracesExporter(Map<String, dynamic> data)?, required bool enableSwizzling, Map<String, dynamic>? traceParentInHeader, List<CxNetworkCaptureRule>? networkCaptureConfig})

Properties

application String
final
beforeSend BeforeSendResult? Function(EditableCxRumEvent event)?
final
collectIPData bool
final
coralogixDomain CXDomain
final
debug bool
final
enableSwizzling bool
final
environment String
final
excludeFromSampling List<CXExcludableInstrumentation>
final
hashCode int
The hash code for this object.
no setterinherited
ignoreErrors List<String>?
final
ignoreUrls List<String>?
final
instrumentations Map<String, bool>?
getter/setter pair
labels Map<String, dynamic>?
getter/setter pair
mobileVitalsFPSSamplingRate int
final
networkCaptureConfig List<CxNetworkCaptureRule>?
final
proxyUrl String?
final
publicKey String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkSampler int
final
traceParentInHeader Map<String, dynamic>?
getter/setter pair
tracesExporter → void Function(Map<String, dynamic> data)?
When set, the native SDK emits completed trace batches as OTLP-style maps to this callback (see native traces exporter). Serialized over the platform bridge separately from toMap.
final
userContext UserMetadata?
getter/setter pair
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited