CoralogixCustomTracer class

Entry point for custom OpenTelemetry-style spans bridged to the native SDK.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startGlobalSpan(String name, {Map<String, dynamic>? labels}) Future<CoralogixGlobalSpan?>
Starts a global (root) span, or null if the native layer refuses (for example when another global span is already active — Q3).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited