MethodChannelCxFlutterPlugin class
An implementation of CxFlutterPluginPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- CxFlutterPluginPlatform
- MethodChannelCxFlutterPlugin
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureScreenshot(
) → Future< void> -
override
-
getLabels(
) → Future< Map< String, dynamic> ?> -
override
-
getSessionId(
) → Future< String?> -
override
-
getSessionReplayFolderPath(
) → Future< String?> -
override
-
initializeSessionReplay(
CXSessionReplayOptions options) → Future< String?> -
override
-
initSdk(
CXExporterOptions options) → Future< String?> -
override
-
isInitialized(
) → Future< bool> -
override
-
isRecording(
) → Future< bool> -
override
-
isSessionReplayInitialized(
) → Future< bool> -
override
-
log(
CxLogSeverity severity, String message, Map< String, dynamic> data) → Future<String?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerMaskRegion(
String id) → Future< void> -
override
-
reportError(
String message, Map< String, dynamic> ? data, String? stackTrace) → Future<String?> -
override
-
sendCustomMeasurement(
String name, double value) → Future< String?> -
override
-
sendCxSpanData(
dynamic cxSpan(Map< String, dynamic> )) → Future<String?> -
inherited
-
setApplicationContext(
String applicationName, String applicationVersion) → Future< String?> -
override
-
setLabels(
Map< String, dynamic> labels) → Future<String?> -
override
-
setNetworkRequestContext(
Map< String, dynamic> networkRequestContext) → Future<String?> -
override
-
setUserContext(
UserMetadata userContext) → Future< String?> -
override
-
setUserInteraction(
Map< String, dynamic> interactionDataContext) → Future<String?> -
override
-
setView(
String name) → Future< String?> -
override
-
shutdown(
) → Future< String?> -
override
-
shutdownSessionReplay(
) → Future< void> -
override
-
startSessionRecording(
) → Future< void> -
override
-
stopListening(
) → void -
stopSessionRecording(
) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unregisterMaskRegion(
String id) → Future< void> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- onParsedStackTrace ↔ void Function(ParsedStackTrace)?
-
Called with the ParsedStackTrace produced by reportError before it is
forwarded to native. Set this in integration tests to capture and assert
on the parsed payload without intercepting the method channel.
getter/setter pair