CxFlutterPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CxFlutterPluginPlatform
Implementers

Constructors

CxFlutterPluginPlatform()
Constructs a CxFlutterPluginPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

captureScreenshot() Future<void>
endSpan(String spanId) Future<void>
getLabels() Future<Map<String, dynamic>?>
getSessionId() Future<String?>
getSessionReplayFolderPath() Future<String?>
initializeSessionReplay(CXSessionReplayOptions options) Future<String?>
initSdk(CXExporterOptions options) Future<String?>
isInitialized() Future<bool>
isRecording() Future<bool>
isSessionReplayInitialized() Future<bool>
log(CxLogSeverity severity, String message, Map<String, dynamic> data) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerMaskRegion(String id) Future<void>
reportError(String message, Map<String, dynamic>? data, String? stackTrace) Future<String?>
sendCustomMeasurement(String name, double value) Future<String?>
sendCxSpanData(dynamic cxSpan(Map<String, dynamic>)) Future<String?>
setApplicationContext(String applicationName, String applicationVersion) Future<String?>
setLabels(Map<String, dynamic> labels) Future<String?>
setNetworkRequestContext(Map<String, dynamic> networkRequestContext) Future<String?>
setUserContext(UserMetadata userContext) Future<String?>
setUserInteraction(Map<String, dynamic> interactionDataContext) Future<String?>
setView(String name) Future<String?>
shutdown() Future<String?>
shutdownSessionReplay() Future<void>
startCustomSpan({required String parentSpanId, required String name, Map<String, dynamic>? labels}) Future<Map<String, dynamic>?>
startGlobalSpan({required String name, Map<String, dynamic>? labels, required List<String> ignoredInstruments}) Future<Map<String, dynamic>?>
Starts a global custom span on the native SDK. Returns null if the SDK refuses (e.g. another global span is active).
startSessionRecording() Future<void>
stopSessionRecording() Future<void>
toString() String
A string representation of this object.
inherited
unregisterMaskRegion(String id) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CxFlutterPluginPlatform
The default instance of CxFlutterPluginPlatform to use.
getter/setter pair