ParsedStackTrace class

Constructors

ParsedStackTrace({required String type, required List<Map<String, dynamic>> frames, String? arch, String? buildId, int droppedFrameCount = 0})
const

Properties

arch String?
final
buildId String?
final
droppedFrameCount int
Count of obfuscated frames that matched #NN abs … but were dropped because their symbol was not a Dart snapshot (e.g. Flutter engine, OS framework). Lets consumers distinguish "all frames filtered" from "parser found nothing" when frames is empty. Always 0 for symbolicated traces.
final
frames List<Map<String, dynamic>>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited