NetworkRequestContext class

Annotations
  • @JsonSerializable.new()

Constructors

NetworkRequestContext({required String method, required int statusCode, required String url, String? fragments, String? host, String? schema, String? statusText, int? responseContentLength, int duration = 0})
NetworkRequestContext.fromJson(Map<String, dynamic> json)
factory

Properties

duration int
getter/setter pair
fragments String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
host String?
getter/setter pair
method String
getter/setter pair
responseContentLength int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema String?
getter/setter pair
statusCode int
getter/setter pair
statusText String?
getter/setter pair
url String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited