-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasRecording
↔ bool
-
getter/setter pair
-
isSessionSampledIn
↔ bool
-
Whether the session this event belongs to was sampled in by
sdkSampler / sessionSampleRate. false means the event reached export
only because its category is listed in
CXExporterOptions.excludeFromSampling while the session itself was
sampled out.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessionCreationDate
↔ num?
-
getter/setter pair
-
sessionId
↔ String?
-
getter/setter pair
-
userEmail
↔ String?
-
getter/setter pairinherited
-
userId
↔ String
-
getter/setter pairinherited
-
userMetadata
↔ Map<String, dynamic>?
-
getter/setter pairinherited
-
userName
↔ String?
-
getter/setter pairinherited