SessionReplayMasking class

Constructors

SessionReplayMasking()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

maskAllTextsForTesting bool
no setter
textsToMaskForTesting List<RegExp>
no setter

Static Methods

collectTextRegionsForTesting({List<RegExp>? patterns}) List<Map<String, dynamic>>
initialize({bool maskAllTexts = false, List<String>? textsToMask}) Future<void>
registerRegion(String id) Future<void>
resetForTesting() → void
unregisterRegion(String id) Future<void>

Constants

methodChannel → const MethodChannel