cx_types library
Classes
- CxRumEvent
- DeviceContext
- Device context. Serializes with toJson using keys expected by the schema validator (os, osVersion). fromJson accepts both validator keys and native keys (operating_system, os_version) so events from native round-trip correctly.
- DeviceState
- EditableCxRumEvent
- ErrorContext
- EventContext
- InitInternalContext
- InstrumentationData
- InteractionContext
- InternalContext
- InternalEventInitData
- LifeCycleContext
- LogContext
- MeasurementContext
- MobileSdk
- MobileVitalsContext
- NetworkRequestContext
- OtelResource
- OtelSpan
- SessionContext
- SnapshotContext
- SpanStatus
- UserMetadata
- VersionMetaData
- ViewContext