ErrorContext class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
ErrorContext({String? domain, String? code, String? errorMessage, String? userInfo, List<
Map< ? originalStacktrace, String? errorType, bool? isCrashed, String? eventType, String? errorContext, String? crashTimestamp, String? processName, String? applicationIdentifier, String? triggeredByThread, String? baseAddress, String? arch, List<String, dynamic> >Map< ? threads})String, dynamic> > -
ErrorContext.fromJson(Map<
String, dynamic> json) -
factory
Properties
- applicationIdentifier ↔ String?
-
getter/setter pair
- arch ↔ String?
-
getter/setter pair
- baseAddress ↔ String?
-
getter/setter pair
- code ↔ String?
-
getter/setter pair
- crashTimestamp ↔ String?
-
getter/setter pair
- domain ↔ String?
-
getter/setter pair
- errorContext ↔ String?
-
getter/setter pair
- errorMessage ↔ String?
-
getter/setter pair
- errorType ↔ String?
-
getter/setter pair
- eventType ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCrashed ↔ bool?
-
getter/setter pair
-
originalStacktrace
↔ List<
Map< ?String, dynamic> > -
getter/setter pair
- processName ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
threads
↔ List<
Map< ?String, dynamic> > -
getter/setter pair
- triggeredByThread ↔ String?
-
getter/setter pair
- userInfo ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited