InteractionContext class

Constructors

InteractionContext({String? elementId, String? eventName, String? targetElement, String? elementClasses, String? targetElementInnerText, String? scrollDirection, Map<String, dynamic>? attributes})
InteractionContext.fromJson(Map<String, dynamic> json)
factory

Properties

attributes Map<String, dynamic>?
final
elementClasses String?
getter/setter pair
elementId String?
getter/setter pair
eventName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection String?
getter/setter pair
targetElement String?
getter/setter pair
targetElementInnerText String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes to the same keys as iOS InteractionContext.getDictionary(): event_name, target_element, element_classes, element_id, target_id, target_element_inner_text, scroll_direction, attributes. Emits both element_id and target_id when elementId is set so Android (target_id) and legacy (element_id) both work. Optional fields are only included when non-null to match the SDK.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited