InternalEventInitData class
Constructors
-
InternalEventInitData({required String applicationName, required Map<
String, dynamic> ? labels, required String environment, required String version, required UserMetadata userContext, required ViewContext viewContext, required Map<String, bool> instrumentations, required Map<String, bool> mobileVitalsOptions, required List<String> ignoreUrls, required List<String> ignoreErrors, required bool collectIPData, required int sessionSampleRate, required Map<String, dynamic> traceParentInHeader, required bool debug, String? proxyUrl, String? beforeSend}) -
const
-
InternalEventInitData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- applicationName → String
-
final
- beforeSend → String?
-
final
- collectIPData → bool
-
final
- debug → bool
-
final
- environment → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ignoreErrors
→ List<
String> -
final
-
ignoreUrls
→ List<
String> -
final
-
instrumentations
→ Map<
String, bool> -
final
-
labels
→ Map<
String, dynamic> ? -
final
-
mobileVitalsOptions
→ Map<
String, bool> -
final
- proxyUrl → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionSampleRate → int
-
final
-
traceParentInHeader
→ Map<
String, dynamic> -
final
- userContext → UserMetadata
-
final
- version → String
-
final
- viewContext → ViewContext
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited